@@ -2,7 +2,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2020 by Dominique Dumont.
+# This software is Copyright (c) 2005-2021 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -214,6 +214,16 @@ return [
                 type     => 'check_list',
                 refer_to => '- hash_a + ! hash_b',
             },
+            a_boolean => {
+                type       => 'leaf',
+                value_type => 'boolean',
+            },
+            yes_no_boolean => {
+                type       => 'leaf',
+                value_type => 'boolean',
+                upstream_default => 'yes',
+                write_as => [ 'no', 'yes' ],
+            },
             my_reference => {
                 type       => 'leaf',
                 value_type => 'reference',
