@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2019 by Dominique Dumont.
+# This software is Copyright (c) 2005-2021 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -57,7 +57,7 @@ my @tests = (
         config_file => '/home/foo/strap-igep0020.conf',
         load_check => 'skip',
         log4perl_load_warnings => [
-            [ 'User', (warn => qr/deprecated/) x 2 ]  ,
+            [ 'User', warn => qr/deprecated/ ]  ,
             [ 'User' , ( warn => qr/skipping/) x 2 ]
         ],
     },
